@@ -20,7 +20,7 @@ class Respuesta(BaseModel):
 
     categoria: types.CategoriaOrdenPago
     err_codigo: Optional[types.CodigoError] = Field(default=None, validate_default=True)
-    id: Optional[int] = None
+    id: Optional[str] = None
     fecha_oper: Optional[int] = None
     err_descripcion: Optional[str] = None
     model_config = ConfigDict(use_enum_values=True)
