@@ -71,6 +71,7 @@ class PrioridadOrdenPago(str, Enum):
 
 
 class CategoriaOrdenPago(str, Enum):
+    unknown = ''
     ensesion = 'ENSESION'
     respuesta = 'RESPUESTA'
     cargar_odp = 'CARGAR_ODP'
@@ -141,6 +142,7 @@ class TopologiaOrdenPago(str, Enum):
 
 
 class TipoDevolucionOrdenPago(str, Enum):
+    invalid_cause = -1
     account_not_found = 1
     account_blocked = 2
     account_canceled = 3
